=======================
Contribution Guidelines
=======================


Whether reporting bugs, discussing improvements and new ideas or writing extensions: Contributions to Wisper are welcome! Here's how to get started:

1. Check for open issues or open a fresh issue to start a discussion around a feature idea or a bug.

2. Fork the `repository <https://github.com/parkerduckworth/wisper>`_ on GitHub, create a new branch off the master branch and start making your changes.

3. Send a pull request!